@@ -1,12 +1,11 @@
 package Net::Google::Spreadsheets;
+use 5.008001;
 use Any::Moose;
 use Net::Google::DataAPI;
-use namespace::autoclean;
-use 5.008001;
 use Net::Google::AuthSub;
 use Net::Google::DataAPI::Auth::AuthSub;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 with 'Net::Google::DataAPI::Role::Service';
 has gdata_version => (
@@ -69,6 +68,9 @@ sub BUILD {
 
 __PACKAGE__->meta->make_immutable;
 
+no Any::Moose;
+no Net::Google::DataAPI;
+
 1;
 __END__
 
