@@ -1,6 +1,5 @@
 package Net::Google::Spreadsheets::Row;
 use Any::Moose;
-use namespace::autoclean;
 use Net::Google::DataAPI;
 use XML::Atom::Util qw(nodelist);
 
@@ -26,6 +25,9 @@ around to_atom => sub {
 
 __PACKAGE__->meta->make_immutable;
 
+no Any::Moose;
+no Net::Google::DataAPI;
+
 1;
 __END__
 
